<?php

/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace GlennArkell\Component\Gavoting\Administrator\View\Positions;

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Application\CMSApplication;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\MVC\View\GenericDataException;
use \Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use \Joomla\CMS\Toolbar\Toolbar;
use \Joomla\CMS\Toolbar\ToolbarHelper;
use \Joomla\CMS\Helper\ContentHelper;
use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\Component\ComponentHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

/**
 * View class for a list of Gavoting.
 *
 * @since  1.6
 */
class HtmlView extends BaseHtmlView
{
	protected $items;

	protected $pagination;

	protected $state;

	public $filterForm;

	public $activeFilters;

	/**
	 * Display the view
	 * @param   string  $tpl  Template name
	 * @return void
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$this->state = $this->get('State');
		$this->items = $this->get('Items');
		$this->pagination = $this->get('Pagination');
        $this->filterForm = $this->get('FilterForm');
        $this->activeFilters = $this->get('ActiveFilters');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			throw new GenericDataException(implode("\n", $errors), 500);
		}

		$this->addToolbar();

        HTMLHelper::stylesheet(Uri::base().'media/com_gavoting/css/gavoting.css');
        HTMLHelper::stylesheet(Uri::base().'media/com_gavoting/css/list.css');

		return parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 * @return void
	 * @since    1.6
	 */
	protected function addToolbar()
	{
		// Get the toolbar object instance
		$toolbar = Toolbar::getInstance('toolbar');

		ToolbarHelper::title(Text::_('COM_GAVOTING_TITLE_POSITIONS'), 'positions.png');

        $toolbar->link('JTOOLBAR_DASHBOARD', 'index.php?option=com_cpanel&view=cpanel&dashboard=gavoting');

		$canDo = ContentHelper::getActions('com_gavoting','component',0);

		// Check if the form exists before showing the add/edit buttons
		$formPath = JPATH_ADMINISTRATOR . '/components/com_gavoting/src/View/Positions';

		if (file_exists($formPath)) {
			if ($canDo->get('core.create')) {
				$toolbar->addNew('position.add');
			}
		}

		if ($canDo->get('core.edit.state')) {
			$dropdown = $toolbar->dropdownButton('status-group')
				->text('JTOOLBAR_CHANGE_STATUS')
				->toggleSplit(false)
				->icon('fa fa-ellipsis-h')
				->buttonClass('btn btn-info')
				->listCheck(true);

			$childBar = $dropdown->getChildToolbar();

			$childBar->publish('positions.publish')->listCheck(true);

			$childBar->unpublish('positions.unpublish')->listCheck(true);

			$childBar->archive('positions.archive')->listCheck(true);

			$childBar->checkin('positions.checkin')->listCheck(true);

			if ($this->state->get('filter.state') != -2) {
				$childBar->trash('positions.trash')->listCheck(true);
			}
		}

		if ($this->state->get('filter.state') == -2 && $canDo->get('core.delete')) {
			$toolbar->delete('positions.delete')
				->text('JTOOLBAR_EMPTY_TRASH')
				->message('JGLOBAL_CONFIRM_DELETE')
				->listCheck(true);
		}

		$nRecords = $this->pagination->total;
		$toolbar->standardButton('nrecords')
		->icon('fa fa-info-circle')
		->text($nRecords . ' Positions')
		->task('')
		->onclick('return false')
		->listCheck(false);

        $compVersion = GavotingHelper::getComponentVersion();
		$toolbar->standardButton('compVers')
			->icon('fas fa-code-branch')
			->text($compVersion)
			->task('')
			->onclick('return false')
			->listCheck(false);

		if ($canDo->get('core.admin')) {

			$params = ComponentHelper::getParams('com_gavoting');
			$testComp = $params->get('test_comp', 0);
            
            if ($testComp) {
                $toolbar->standardButton('positions.resetZero')
            		->icon('fas fa-history')
            		->text('JTOOLBAR_CLEARFIELDS')
            		->task('positions.resetZero')
            		->onclick('return false')
            		->listCheck(true);
            }

			$toolbar->preferences('com_gavoting');
		}

	}

	/**
	 * Returns an array of fields the table can be sorted by
	 * @return  array  Array containing the field name to sort by as the key and display text as value
	 * @since   3.0
	 */
	protected function getSortFields()
	{
		return array(
			'a.pos_name'     => Text::_('COM_GAVOTING_FORM_LBL_POSITION_POS_NAME'),
			'a.id'           => Text::_('JGRID_HEADING_ID'),
		);
	}
}
