<?php

/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace GlennArkell\Component\Gavoting\Site\Controller;

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Session\Session;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Controller\FormController;
use \Joomla\CMS\Component\ComponentHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

/**
 * Voter controller class.
 *
 * @since  1.6
 */
class VoterformController extends FormController
{
	/**
	 * Method to check out an item for editing and redirect to the edit form.
	 * @return void
	 * @since    1.6
     * @throws Exception
	 */
	public function edit($key = NULL, $urlVar = NULL)
	{
		$app = Factory::getApplication();

		// Get the previous edit id (if any) and the current edit id.
		$previousId = (int) $app->getUserState('com_gavoting.edit.voter.id');
		$editId     = $app->input->getInt('id', 0);

		// Set the record id for the user to edit in the session.
		$app->setUserState('com_gavoting.edit.voter.id', $editId);

		// Get the model.
		$model = $this->getModel('Voterform', 'Site');

		// Check out the item
		if ($editId)
		{
			$model->checkout($editId);
		}

		// Check in the previous user.
		if ($previousId)
		{
			$model->checkin($previousId);
		}

		// Redirect to the edit screen.
		$this->setRedirect(Route::_('index.php?option=com_gavoting&view=voterform&layout=edit', false));
	}

	/**
	 * Method to save a user's profile data.
	 * @return void
	 * @throws Exception
	 * @since  1.6
	 */
	public function save($key = NULL, $urlVar = NULL)
	{
		// Check for request forgeries.
		Session::checkToken() or jexit(Text::_('JINVALID_TOKEN'));

		// Initialise variables.
		$app   = Factory::getApplication();
		$model = $this->getModel('Voterform', 'Site');

		// Get the submitted data.
		$data = Factory::getApplication()->input->get('jform', array(), 'array');
 
		// cycle through for multiple seats and check if too many
		// number of seats is irrelevant if preferential voting
		// because there is one value for each nom_ids thus values not array
        foreach ($data['nom_ids'] as $keys => $values) {
	        $key = explode('_',$keys);
	        $posID = $key[2];
	        //$posNom = $key[3];
            if (is_array($values)) {
				$posit = GavotingHelper::getPosition($posID);
				$pos_name = $posit->position_name;
				if (count($values) > $posit->pos_qty) {
					$app->enqueueMessage(Text::sprintf('COM_GAVOTING_MULTISELECT_EXCEEDED', $posit->position_name), 'warning');
					// Save the data in the session.
					$app->setUserState('com_gavoting.edit.voter.data', $data);
					// Redirect back to the edit screen.
					$id = (int) $app->getUserState('com_gavoting.edit.voter.id');
					$this->setRedirect(Route::_('index.php?option=com_gavoting&view=voterform&layout=edit&id='.$id, false));
					$this->redirect();
				}
			}
		}
		// Attempt to save the data.
		$return = $model->save($data);

		// Check for errors.
		if ($return === false)
		{
			// Save the data in the session.
			$app->setUserState('com_gavoting.edit.voter.data', $data);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_gavoting.edit.voter.id');
			$this->setMessage(Text::sprintf('Save failed', $model->getError()), 'warning');
			$this->setRedirect(Route::_('index.php?option=com_gavoting&view=voterform&layout=edit&id=' . $id, false));
		}

		// Check in the record.
		if ($return)
		{
			$model->checkin($return);
		}

		// Clear the record id from the session.
		$app->setUserState('com_gavoting.edit.voter.id', null);

        $menu = $app->getMenu();
        $item = $menu->getActive();
        $url = (empty($item->link) ? 'index.php?option=com_gavoting&view=nominations' : $item->link);
		// Redirect to the list screen.
		$this->setMessage(Text::_('COM_GAVOTING_ITEM_SAVED_SUCCESSFULLY'), 'success');
		$this->setRedirect(Route::_($url, false));

		// Flush the data from the session.
		$app->setUserState('com_gavoting.edit.voter.data', null);
	}

	/**
	 * Method to abort current operation
	 * @return void
	 * @throws Exception
	 */
	public function cancel($key = NULL)
	{
		$app = Factory::getApplication();

		// Get the current edit id.
		$editId = (int) $app->getUserState('com_gavoting.edit.voter.id');

		// Get the model.
		$model = $this->getModel('Voterform', 'Site');

		// Check in the item
		if ($editId)
		{
			$model->checkin($editId);
		}

		$item = Factory::getApplication()->getMenu()->getActive();
		if (!$item){
			// If there isn't any menu item active, redirect to list view
			$this->setRedirect(Route::_('index.php?option=com_gavoting&view=nominations', false));
		} else {
            $this->setRedirect(Route::_('index.php?Itemid='. $item->id, false));
		}
	}

	/**
	 * Method to remove data
	 * @return void
	 * @throws Exception
     * @since 1.6
	 */
	public function remove()
    {
        $app   = Factory::getApplication();
        $model = $this->getModel('Voterform', 'Site');
        $pk    = $app->input->getInt('id');

        // Attempt to update the data
        try
        {
            $return = $model->delete($pk);

            // Check in the record
            $model->checkin($return);

            // Clear the record id from the session.
            $app->setUserState('com_gavoting.edit.voter.id', null);

            // Redirect to the list screen
            $this->setMessage(Text::_('COM_GAVOTING_ITEM_DELETED_SUCCESSFULLY'), 'success');
            $this->setRedirect(Route::_('index.php?option=com_gavoting&view=voters', false));

            // Flush the data from the session.
            $app->setUserState('com_gavoting.edit.voter.data', null);
        }
        catch (Exception $e)
        {
            $errorType = ($e->getCode() == '404') ? 'error' : 'warning';
            $this->setMessage($e->getMessage(), $errorType);
            $this->setRedirect('index.php?option=com_gavoting&view=voters');
        }
    }

	/**
	 * Method to archive data
	 * @return void
	 * @throws Exception
     * @since 1.6
	 */
	public function archive()
    {
        $app   = Factory::getApplication();
        $model = $this->getModel('Voterform', 'Site');
        $pk    = $app->input->getInt('id');

        // Attempt to update the data
        try
        {
            $return = $model->archive($pk);

            // Check in the record
            $model->checkin($return);

            // Clear the record id from the session.
            $app->setUserState('com_gavoting.edit.voter.id', null);

            // Redirect to the list screen
            $this->setMessage(Text::_('COM_GAVOTING_ITEM_ARCHIVED_SUCCESSFULLY'), 'success');
            $this->setRedirect(Route::_('index.php?option=com_gavoting&view=voters', false));

            // Flush the data from the session.
            $app->setUserState('com_gavoting.edit.voter.data', null);
        }
        catch (Exception $e)
        {
            $errorType = ($e->getCode() == '404') ? 'error' : 'warning';
            $this->setMessage($e->getMessage(), $errorType);
            $this->setRedirect('index.php?option=com_gavoting&view=voters');
        }
    }

	/**
	 * Method to record a vote decision
	 * @return void
	 */
	public function voteDecision()
    {
        $app   = Factory::getApplication();
        $model = $this->getModel('Voterform', 'Site');

        // Attempt to update the data
        try
        {
            $return = $model->voteDecision();

            if ($return) {
                $this->setMessage(Text::_('COM_GAVOTING_ELECTION_SUCCESSFULLY'), 'success');
            } else {
                $this->setMessage(Text::_('COM_GAVOTING_ELECTION_FAILED'), 'warning');
            }
            // Redirect to the list screen
            $this->setRedirect(Route::_('index.php?option=com_gavoting&view=nominations', false));
        }
        catch (Exception $e)
        {
            $errorType = ($e->getCode() == '404') ? Text::_('ERROR') : 'warning';
            $this->setMessage($e->getMessage(), $errorType);
            $this->setRedirect('index.php?option=com_gavoting&view=nominations');
        }
    }

	/**
	 * Method to record a cast deciding vote when candidates tie
	 * @return void
	 */
	public function castDecisionVote()
    {
        $app   = Factory::getApplication();
        $tiePositions = $app->getUserState('com_gavoting.tiepositions.data');
        
        if (empty($tiePositions)) {
            $this->setMessage(Text::_('COM_GAVOTING_NO_TIED_NOMINEES'), 'warning');
            $app->redirect(Route::_('index.php?option=com_gavoting&view=nominations', false));
        }
        
        $model = $this->getModel('Voterform', 'Site');

		// Redirect to the edit screen.
		$this->setRedirect(Route::_('index.php?option=com_gavoting&view=voterform&layout=decide', false));

    }
}
