<?php

/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace GlennArkell\Component\Gavoting\Site\Model;

// No direct access.
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\Utilities\ArrayHelper;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Table\Table;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\Filesystem\Path;
use \Joomla\Filesystem\File;
use \Joomla\Filesystem\Folder;
use \Joomla\CMS\MVC\Model\ItemModel;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

/**
 * Gavoting model.
 *
 * @since  1.6
 */
class NominationModel extends ItemModel
{
    public $_item;

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return void
	 *
	 * @since    1.6
	 *
     * @throws Exception
	 */
	protected function populateState()
	{
		$app  = Factory::getApplication('com_gavoting');
		$user = GavotingHelper::getSpecificUser();

		// Check published state
		if ((!$user->authorise('core.edit.state', 'com_gavoting')) && (!$user->authorise('core.edit', 'com_gavoting')))
		{
			$this->setState('filter.published', 1);
			$this->setState('filter.archived', 2);
		}

		// Load state from the request userState on edit or from the passed variable on default
		if (Factory::getApplication()->input->get('layout') == 'edit')
		{
			$id = Factory::getApplication()->getUserState('com_gavoting.edit.nomination.id');
		}
		else
		{
			$id = Factory::getApplication()->input->get('id');
			Factory::getApplication()->setUserState('com_gavoting.edit.nomination.id', $id);
		}

		$this->setState('nomination.id', $id);

		// Load the parameters.
		$params       = $app->getParams();
		$params_array = $params->toArray();

		if (isset($params_array['item_id']))
		{
			$this->setState('nomination.id', $params_array['item_id']);
		}

		$this->setState('params', $params);
	}

	/**
	 * Method to get an object.
	 *
	 * @param   integer $id The id of the object to get.
	 *
	 * @return  mixed    Object on success, false on failure.
     *
     * @throws Exception
	 */
	public function getItem($id = null)
	{
            if ($this->_item === null)
            {
                $this->_item = false;

                if (empty($id))
                {
                    $id = $this->getState('nomination.id');
                }

                // Get a level row instance.
                $table = $this->getTable();

                // Attempt to load the row.
                if ($table->load($id))
                {
                    

                    // Check published state.
                    if ($published = $this->getState('filter.published'))
                    {
                        if (isset($table->state) && $table->state != $published)
                        {
                            throw new \Exception(Text::_('COM_GAVOTING_ITEM_NOT_LOADED'), 403);
                        }
                    }

                    // Convert the Table to a clean Object.
                    $properties  = $table->getProperties(1);
                    //$this->_item = ArrayHelper::toObject($properties, 'JObject');
                    $this->_item = ArrayHelper::toObject($properties);


                } 
            }
        
		if (isset($this->_item->created_by)) {
			$this->_item->created_by_name = GavotingHelper::getSpecificUser($this->_item->created_by)->name;
		}

		if (isset($this->_item->modified_by)) {
			$this->_item->modified_by_name = GavotingHelper::getSpecificUser($this->_item->modified_by)->name;
		}

		if (isset($this->_item->position_id)) {
			$position = GavotingHelper::getPosition($this->_item->position_id);
			$this->_item->position_id_name = $position->position_name;
			$this->_item->jd_id = $position->jd_id;
		}

		if (isset($this->_item->nom_id)) {
			$this->_item->nomby_name = GavotingHelper::getSpecificUser($this->_item->nom_id)->name;
		}
		if (isset($this->_item->sec_id)) {
			$this->_item->secby_name = GavotingHelper::getSpecificUser($this->_item->sec_id)->name;
		}

        return $this->_item;
    }

	/**
	 * Get an instance of JTable class
	 *
	 * @param   string $type   Name of the JTable class to get an instance of.
	 * @param   string $prefix Prefix for the table class name. Optional.
	 * @param   array  $config Array of configuration values for the JTable object. Optional.
	 *
	 * @return  JTable|bool JTable if success, false on failure.
	 */
    public function getTable($type = 'Nomination', $prefix = 'Administrator', $config = array())
    {
        return parent::getTable($type, $prefix, $config);
    }

	/**
	 * Get the id of an item by alias
	 *
	 * @param   string $alias Item alias
	 *
	 * @return  mixed
	 */
	public function getItemIdByAlias($alias)
	{
            $table      = $this->getTable();
            $properties = $table->getProperties();
            $result     = null;

            if (key_exists('alias', $properties))
            {
                $table->load(array('alias' => $alias));
                $result = $table->id;
            }
            
                return $result;
            
	}

	/**
	 * Method to check in an item.
	 *
	 * @param   integer $id The id of the row to check out.
	 *
	 * @return  boolean True on success, false on failure.
	 *
	 * @since    1.6
	 */
	public function checkin($id = null)
	{
		// Get the id.
		$id = (!empty($id)) ? $id : (int) $this->getState('nomination.id');
                
		if ($id)
		{
			// Initialise the table
			$table = $this->getTable();

			// Attempt to check the row in.
			if (method_exists($table, 'checkin'))
			{
				if (!$table->checkIn($id))
				{
					return false;
				}
			}
		}

		return true;
                
	}

	/**
	 * Method to check out an item for editing.
	 *
	 * @param   integer $id The id of the row to check out.
	 *
	 * @return  boolean True on success, false on failure.
	 *
	 * @since    1.6
	 */
	public function checkout($id = null)
	{
		// Get the user id.
		$id = (!empty($id)) ? $id : (int) $this->getState('nomination.id');

                
		if ($id)
		{
			// Initialise the table
			$table = $this->getTable();

			// Get the current user object.
			$user = GavotingHelper::getSpecificUser();

			// Attempt to check the row out.
			if (method_exists($table, 'checkout'))
			{
				if (!$table->checkOut($user->id, $id))
				{
					return false;
				}
			}
		}

		return true;
                
	}

	/**
	 * Publish the element
	 * @param   int $id    Item id
	 * @param   int $state Publish state
	 * @return  boolean
	 */
	public function publish($id, $state)
	{
		$table = $this->getTable();
                
		$table->load($id);
		$table->state = $state;

		return $table->store(true);
                
	}

	/**
	 * Method to delete an item
	 * @param   int $id Element id
	 * @return  bool
	 */
	public function delete($id)
	{
		$table = $this->getTable();

		$table->load($id);
		$table->state = -2;

		return $table->store(true);
                
	}

	/**
	 * Method to agree a nomination
	 * @param   int $id Element id
	 * @return  bool
	 */
	public function agree($id, $user_id)
	{
		$tz = Factory::getConfig()->get('offset');
		$date = Factory::getDate('now', $tz);
		$today = date_format($date,'Y-m-d H:i:s');
		$table = $this->getTable();

		$table->load($id);
		$table->agreed = 1;
		$table->agreed_date = $today;

		return $table->store(true);
                
	}

	/**
	 * Method to disinclined to acquiesce to your request to nominate
	 * @param   int $id Element id
	 * @return  bool
	 */
	public function reject($id, $user_id)
	{
		$tz = Factory::getConfig()->get('offset');
		$date = Factory::getDate('now', $tz);
		$today = date_format($date,'Y-m-d H:i:s');
		$table = $this->getTable();

		$table->load($id);
		$table->state = -2;
		$table->agreed = 0;
		$table->modified_date = $today;

		return $table->store(true);
                
	}

	/**
	 * Method to agree as seconder for nomination
	 * @param   int $id Element id
	 * @return  bool
	 */
	public function seconder($id, $user_id)
	{
		$table = $this->getTable();

		$table->load($id);
		$table->sec_id = $user_id;

		return $table->store(true);
                
	}

}
