<?php
/**
 * @version    4.5.0
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \Joomla\CMS\User\UserHelper;
use \Joomla\CMS\Date\Date;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

// load any assets required
$this->document->getWebAssetManager()
    ->usePreset('com_gavoting.gavotingpreset');

// Load admin language file
$lang = Factory::getApplication()->getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user       = GavotingHelper::getSpecificUser();
$userId     = $user->id;
$listOrder  = $this->state->get('list.ordering', 'a.mov_date');
$listDirn   = $this->state->get('list.direction', 'ASC');
$canCreate  = $user->authorise('core.create', 'com_gavoting');
$canEdit    = $user->authorise('core.edit', 'com_gavoting');
$canCheckin = $user->authorise('core.manage', 'com_gavoting');
$canChange  = $user->authorise('core.edit.state', 'com_gavoting');
$canDelete  = $user->authorise('core.delete', 'com_gavoting');
$canNominate  = $user->authorise('core.nominate', 'com_gavoting');
$canVote  = $user->authorise('core.vote', 'com_gavoting');
$canMotion  = $user->authorise('core.motion', 'com_gavoting');
$showVotes = $this->params->get('show_votes',0);
$notag_colour = $this->params->get('notag_colour','#a51f18');
$req_sec_mot = $this->params->get('req_sec_mot',1);
$cols = 5;
$padSpace = '&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;';


/*
echo '<pre>Test<br />';
print_r($this->items);
echo '</pre>';
print_r(Factory::getApplication()->getUserState('com_gavoting.test.files'));
print_r(Factory::getApplication()->getUserState('com_gavoting.test.data'));
*/
?>

<h2><?php echo Text::_('COM_GAVOTING_PAST_MOTIONS'); ?></h2>

<form action="<?php echo htmlspecialchars(Uri::getInstance()->toString()); ?>" method="post"
      name="adminForm" id="adminForm" class="com-content-category__articles">

	<?php echo LayoutHelper::render('joomla.searchtools.default', array('view' => $this)); ?>

    <div class="table-responsive">
	<table class="table table-striped" id="motionList">
		<thead>
		<tr>
			<th width="12%" class='center'>
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_MOTIONS_MOV_DATE', 'a.mov_date', $listDirn, $listOrder); ?>
			</th>
			<th width="20%" class="left">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_MOTIONS_MOV_ID', 'mov_id_name', $listDirn, $listOrder); ?>
			</th>
			<th width="20%" class="left">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_MOTIONS_SEC_ID', 'sec_id_name', $listDirn, $listOrder); ?>
			</th>
			<th width="5%" class="center">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_MOTIONS_AGREED', 'a.agreed', $listDirn, $listOrder); ?>
			</th>
			<th width="12%" class="center">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_MOTIONS_AGREED_DATE', 'a.agreed_date', $listDirn, $listOrder); ?>
			</th>
		</tr>
		</thead>
		<tfoot>
		<tr>
			<td colspan="<?php echo isset($this->items[0]) ? count(get_object_vars($this->items[0])) : 10; ?>">
				<?php echo $this->pagination->getListFooter(); ?>
			</td>
		</tr>
		</tfoot>
		<tbody>
		<?php foreach ($this->items as $i => $item) : ?>
			<?php
				$canEdit = $user->authorise('core.edit', 'com_gavoting');
				if (!$canEdit && $user->authorise('core.edit.own', 'com_gavoting')) {
					$canEdit = GavotingHelper::getSpecificUser()->id == $item->motion;
				}
				
				if (!$item->agreed && $item->agreed != null) {
					$nomStyle = ' style="color:'.$notag_colour.';"'; 
				} else { 
					$nomStyle = ''; 
				}
				
			?>


			<tr class="row<?php echo $i % 2; ?>">
				<td<?php echo $nomStyle; ?>>
					<?php if (isset($item->checked_out) && $item->checked_out) : ?>
						<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->uEditor, $item->checked_out_time, 'motions.', $canCheckin); ?>
					<?php endif; ?>
					<?php echo HtmlHelper::date($item->mov_date, Text::_('COM_GAVOTING_DISPLAY_DATE')); ?>
				</td>
				<td class="left"<?php echo $nomStyle; ?>>
					<?php echo $item->mov_id_name; ?>
				</td>
				<td class="left"<?php echo $nomStyle; ?>>

                    <?php if ($req_sec_mot): ?>
						<?php echo $item->sec_id_name; ?>
					<?php else : ?>
						<?php echo Text::_('COM_GAVOTING_NO_SECONDER_REQ'); ?>
					<?php endif; ?>
				</td>
				<td class="center"<?php echo $nomStyle; ?>>
					<?php if ($item->agreed != null) { if ($item->agreed) { echo '<i class="icon-publish"></i>'; } else { echo '<i class="icon-publish"></i>'; } }?>
				</td>
				<td class="center"<?php echo $nomStyle; ?>>
					<?php if ($item->agreed_date == '0000-00-00 00:00:00' || $item->agreed_date == null) { /* do nothing */ } else {echo HtmlHelper::date($item->agreed_date, Text::_('COM_GAVOTING_DISPLAY_DATE')); } ?>
				</td>

			</tr>
			<tr>
				<td<?php echo $nomStyle; ?> colspan="<?php echo $cols; ?>">
					<?php echo $item->motion; ?>
					<?php
                        if ($item->votes_for >= $item->votes_against ) {
                            echo '<p> </p><p><strong>';
                            echo Text::sprintf('COM_GAVOTING_MOTION_CARRIED',$item->votes_for, $item->votes_against);
                            echo '<span style="float:right;">'.Text::_('COM_GAVOTING_CARRIED').'</span></strong></p>';
                        } else {
                            echo '<p> </p><p><strong>';
                            echo Text::sprintf('COM_GAVOTING_MOTION_FAILED',$item->votes_against, $item->votes_for);
                            echo '<span style="float:right;">'.Text::_('COM_GAVOTING_FAILED').'</span></strong></p>';
                        }
                    ?>
				</td>
			</tr>
		<?php endforeach; ?>
		</tbody>
	</table>
    </div>

	<input type="hidden" name="task" value=""/>
	<input type="hidden" name="boxchecked" value="0"/>
	<input type="hidden" name="filter_order" value="<?php echo $listOrder; ?>"/>
	<input type="hidden" name="filter_order_Dir" value="<?php echo $listDirn; ?>"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>
