<?php
/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

// load any assets required
$this->document->getWebAssetManager()
    ->usePreset('com_gavoting.gavotingpreset');

// Load admin language file
$lang = Factory::getApplication()->getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user    = GavotingHelper::getSpecificUser();
$canCheckin = $user->authorise('core.manage', 'com_gavoting');
$canNominate  = $user->authorise('core.nominate', 'com_gavoting');
$canEdit = GavotingHelper::canUserEdit($this->item, $user);
$close_noms = GavotingHelper::nominationsClosed();
$today = GavotingHelper::getTodaysDate();
$canNomAny = $this->params->get('allow_anynom', 0);
$reqSecNom = $this->params->get('req_sec_nom', 0);
$allowSecNom = $this->params->get('allow_sec_nom', 0);

if ($canNomAny) {
    // nothing to change here
} elseif (!$canCheckin) {
    $this->form->setFieldAttribute('nomination', 'readonly', 'readonly');
    $this->form->setFieldAttribute('nomination', 'default', $user->id);
}
if (!$canCheckin) {
    $this->form->setFieldAttribute('nom_id', 'readonly', 'readonly');
    $this->form->setFieldAttribute('nom_id', 'default', $user->id);
}
if ($reqSecNom && $allowSecNom) {
    // nothing to change here
} elseif (!$canCheckin) {
    $this->form->setFieldAttribute('sec_id', 'type', 'hidden');
    $this->form->setFieldAttribute('sec_id', 'default', 0);
}
?>

<div class="nomination-edit front-end-edit">
	<?php if ($close_noms) : ?>
		<h3>
			<?php echo Text::_('COM_GAVOTING_NOMINATIONS_CLOSED'); ?>
		</h3>
	<?php else : ?>
		<?php if (!$canNominate) : ?>
			<h3>
				<?php throw new \Exception(Text::_('COM_GAVOTING_ERROR_MESSAGE_NOT_AUTHORISED'), 403); ?>
			</h3>
		<?php else : ?>
			<h2><?php echo Text::_('COM_GAVOTING_TITLE_NOMINATION'); ?></h2>
			<?php if ($reqSecNom) : ?>
                <h3><?php echo Text::_('COM_GAVOTING_NOMINATION_SUBMIT_TEXT'); ?></h3>
	        <?php endif; ?>

			<form id="form-nomination"
				  action="<?php echo Route::_('index.php?option=com_gavoting&task=nominationform.save'); ?>"
				  method="post" class="form-validate form-horizontal" enctype="multipart/form-data">
	            <?php if ($this->item) : ?>
					<input type="hidden" name="jform[id]" value="<?php echo $this->item->id; ?>" />
					<input type="hidden" name="jform[ordering]" value="<?php echo $this->item->ordering; ?>" />
					<input type="hidden" name="jform[state]" value="<?php echo $this->item->state; ?>" />
					<input type="hidden" name="jform[checked_out]" value="<?php echo $this->item->checked_out; ?>" />
					<input type="hidden" name="jform[checked_out_time]" value="<?php echo $this->item->checked_out_time; ?>" />
					<input type="hidden" name="jform[created_by]" value="<?php echo $this->item->created_by; ?>" />
					<input type="hidden" name="jform[modified_by]" value="<?php echo $this->item->modified_by; ?>" />
					<input type="hidden" name="jform[created_date]" value="<?php echo $this->item->created_date; ?>" />
					<input type="hidden" name="jform[modified_date]" value="<?php echo $this->item->modified_date; ?>" />
				<?php else : ?>
					<input type="hidden" name="jform[id]" value="0" />
				<?php endif; ?>
				<input type="hidden" name="jform[nom_date]" value="<?php echo $today; ?>" />
	
				<?php echo HTMLHelper::_('bootstrap.startTabSet', 'myTab', array('active' => 'nomination')); ?>
				<?php echo HTMLHelper::_('bootstrap.addTab', 'myTab', 'nomination', Text::_('COM_GAVOTING_TAB_NOMINATION', true)); ?>
				<div class="row-fluid">
					<div class="span10 form-horizontal">
						<fieldset class="adminform">
							<legend><?php echo Text::_('COM_GAVOTING_FIELDSET_NOMINATION'); ?></legend>

							<?php echo $this->form->renderField('position_id'); ?>
                            <?php echo $this->form->renderField('nomination'); ?>

							<?php if ($this->params->get('single_mship',0)) : ?>
								<?php echo $this->form->renderField('oth_mbr'); ?>
                            	<div class="control-group-tight">
                                	<?php echo $this->form->renderField('spacery'); ?>
                                	<?php echo $this->form->renderField('spacern'); ?>
                            	</div>
							<?php endif; ?>

                            <?php echo $this->form->renderField('nom_id'); ?>
                            <?php echo $this->form->renderField('sec_id'); ?>

						</fieldset>
					</div>
				</div>
				<?php echo HTMLHelper::_('bootstrap.endTab'); ?>

				<?php echo HTMLHelper::_('bootstrap.endTabSet'); ?>
	
				<div class="control-group">
					<div class="controls">
	
						<?php if ($canNominate): ?>
							<button type="submit" class="validate btn btn-primary">
								<?php echo Text::_('JSUBMIT'); ?>
							</button>
						<?php endif; ?>
						<a class="btn btn-secondary"
						   href="<?php echo Route::_('index.php?option=com_gavoting&task=nominationform.cancel'); ?>"
						   title="<?php echo Text::_('JCANCEL'); ?>">
							<?php echo Text::_('JCANCEL'); ?>
						</a>
					</div>
				</div>
	
				<input type="hidden" name="option" value="com_gavoting"/>
				<input type="hidden" name="task"
					   value="nominationform.save"/>
				<?php echo HTMLHelper::_('form.token'); ?>
			</form>
		<?php endif; ?>
	<?php endif; ?>
</div>
