<?php
/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\Layout\LayoutHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

// load any assets required
$this->document->getWebAssetManager()
    ->usePreset('com_gavoting.gavotingpreset');

// Load admin language file
$lang = Factory::getApplication()->getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user    = GavotingHelper::getSpecificUser();
$canEdit = GavotingHelper::canUserEdit($this->item, $user);
$canCheckin = $user->authorise('core.manage', 'com_gavoting');
$canVote = $user->authorise('core.vote', 'com_gavoting');
$votingClosed = GavotingHelper::votingClosed();
$hasVoted = GavotingHelper::hasVoted($user->id, 0, 0);
$hasProxy = GavotingHelper::hasProxy($user->id);

$allow_proxy = $this->params->get('allow_proxy',0);
$restrict_voters = $this->params->get('restrict_voters',0);
$voters_user_gp = $this->params->get('voters_user_gp',0);
if ($canVote && $restrict_voters) {
	$canVote = GavotingHelper::checkAccessGroup($user->id, $voters_user_gp);
}

?>

<?php if (!$canVote) : ?>
	<h3><?php echo Text::_('COM_GAVOTING_ERROR_MESSAGE_NOT_AUTHORISED'); ?></h3>
<?php elseif (!$allow_proxy) : ?>
	<h3><?php echo Text::_('COM_GAVOTING_NOT_ALLOWED_PROXY'); ?></h3>
<?php else : ?>
	<?php if ($hasProxy): ?>
		<?php echo Text::sprintf('COM_GAVOTING_ALREADY_PROXYED', $hasProxy->principal, $hasProxy->principal); ?>
	<?php else : ?>
		<?php if ($hasVoted): ?>
			<h2><?php echo Text::_('COM_GAVOTING_ALREADY_VOTED'); ?></h2>
		<?php else : ?>

			<h2><?php echo Text::_('COM_GAVOTING_SET_YOUR_NOMINATED_PROXY'); ?></h2>
	
			<form id="form-position"
				  action="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.save'); ?>"
				  method="post" class="form-validate form-horizontal" enctype="multipart/form-data">
				
				<input type="hidden" name="jform[id]" value="<?php echo $this->item->id; ?>" />
				<input type="hidden" name="jform[ordering]" value="<?php echo $this->item->ordering; ?>" />
				<input type="hidden" name="jform[state]" value="<?php echo $this->item->state; ?>" />
				<input type="hidden" name="jform[checked_out]" value="<?php echo $this->item->checked_out; ?>" />
				<input type="hidden" name="jform[checked_out_time]" value="<?php echo $this->item->checked_out_time; ?>" />
				<input type="hidden" name="jform[created_by]" value="<?php echo $this->item->created_by; ?>" />
				<input type="hidden" name="jform[modified_by]" value="<?php echo $this->item->modified_by; ?>" />
				<input type="hidden" name="jform[created_date]" value="<?php echo $this->item->created_date; ?>" />
				<input type="hidden" name="jform[modified_date]" value="<?php echo $this->item->modified_date; ?>" />
				<input type="hidden" name="jform[cat_id]" value="<?php echo $this->item->cat_id; ?>" />
	
				<?php echo $this->form->renderField('cat_id_name'); ?>
				<?php if ($canCheckin) : ?>
					<?php echo $this->form->renderField('voter_id'); ?>
				<?php else : ?>
					<?php echo $this->form->renderField('voter_id_name'); ?>
					<input type="hidden" name="jform[voter_id]" value="<?php echo $this->item->voter_id; ?>" />
				<?php endif; ?>
				<?php echo $this->form->renderField('user_id'); ?>
	
				<div class="control-group">
					<div class="controls">
						<button type="submit" class="validate btn btn-primary"><?php echo Text::_('JSUBMIT'); ?></button>
					</div>
				</div>
	
				<input type="hidden" name="option" value="com_gavoting"/>
				<input type="hidden" name="task" value="proxyvoterform.save"/>
				<?php echo HTMLHelper::_('form.token'); ?>
			</form>
		<?php endif; ?>
	<?php endif; ?>
<?php endif; ?>
