<?php
/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

// load any assets required
$this->document->getWebAssetManager()
    ->usePreset('com_gavoting.gavotingpreset');

// Load admin language file
$lang = Factory::getApplication()->getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user       = GavotingHelper::getSpecificUser();
$userId     = $user->id;
$listOrder  = $this->state->get('list.ordering', 'v.name');
$listDirn   = $this->state->get('list.direction', 'ASC');
$canCreate  = $user->authorise('core.create', 'com_gavoting');
$canEdit    = $user->authorise('core.edit', 'com_gavoting');
$canCheckin = $user->authorise('core.manage', 'com_gavoting');
$canChange  = $user->authorise('core.edit.state', 'com_gavoting');
$canDelete  = $user->authorise('core.delete', 'com_gavoting');
$canVote    = $user->authorise('core.vote', 'com_gavoting');

$restrict_voters = $this->params->get('restrict_voters',0);
$voters_user_gp = $this->params->get('voters_user_gp',0);
if ($canVote && $restrict_voters) {
	$canVote = GavotingHelper::checkAccessGroup($user->id, $voters_user_gp);
}

?>

<h2><?php echo Text::_('COM_GAVOTING_TITLE_PROXYVOTERS'); ?></h2>

<form action="<?php echo htmlspecialchars(Uri::getInstance()->toString()); ?>" method="post"
      name="adminForm" id="adminForm" class="com-content-category__articles">

	<?php
        // display standard joomla filter files
        //echo LayoutHelper::render('joomla.searchtools.default', array('view' => $this));
        // display component view specific filter files
        echo LayoutHelper::render('default_filter', array('view' => $this), dirname(__FILE__));
    ?>

    <div class="com-contact-categories categories-list">
	<table class="table table-striped" id="proxyvoterList">
		<thead>
		<tr>
			<?php if (isset($this->items[0]->state)): ?>
				<th width="5%">
					<?php echo HTMLHelper::_('grid.sort', 'JSTATUS', 'a.state', $listDirn, $listOrder); ?>
				</th>
			<?php endif; ?>

			<th class=''>
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_PROXYVOTERS_USER_ID', 'v.name', $listDirn, $listOrder); ?>
			</th>
			<th class='center'>
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_PROXYVOTERS_VOTER_ID', 'voter_id_name', $listDirn, $listOrder); ?>
			</th>
			<th class='center'>
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_CREATED_DATE', 'a.created_date', $listDirn, $listOrder); ?>
			</th>

			<?php if ($canEdit || $canDelete): ?>
				<th width="15%" class="center"><?php echo Text::_('COM_GAVOTING_ACTIONS'); ?></th>
			<?php endif; ?>

		</tr>
		</thead>
		<tfoot>
		<tr>
			<td colspan="<?php echo isset($this->items[0]) ? count(get_object_vars($this->items[0])) : 10; ?>">
				<?php echo $this->pagination->getListFooter(); ?>
			</td>
		</tr>
		</tfoot>
		<tbody>
		<?php foreach ($this->items as $i => $item) : ?>
			<?php $canEdit = $user->authorise('core.edit', 'com_gavoting'); ?>

			<?php if (!$canEdit && $user->authorise('core.edit.own', 'com_gavoting')): ?>
				<?php $canEdit = GavotingHelper::getSpecificUser()->id == $item->created_by; ?>
			<?php endif; ?>

			<tr class="row<?php echo $i % 2; ?>">

				<?php if (isset($this->items[0]->state)) : ?>
					<?php $class = ($canChange) ? 'active' : 'disabled'; ?>
					<td class="center">
						<?php if ($item->state == -2): ?>
						<a class="btn btn-micro <?php echo $class; ?>" href="<?php echo ($canChange) ? Route::_('index.php?option=com_gavoting&task=proxyvoter.publish&id=' . $item->id . '&state=' . ((0) % 2), false, 2) : '#'; ?>">
						<?php else : ?>
						<a class="btn btn-micro <?php echo $class; ?>" href="<?php echo ($canChange) ? Route::_('index.php?option=com_gavoting&task=proxyvoter.publish&id=' . $item->id . '&state=' . (($item->state + 1) % 2), false, 2) : '#'; ?>">
						<?php endif; ?>
						<?php if ($item->state == 1): ?>
							<i class="icon-publish" title="Active"></i>
						<?php elseif ($item->state == 0): ?>
							<i class="icon-unpublish" title="Not Active"></i>
						<?php elseif ($item->state == -2): ?>
							<i class="icon-trash" title="Trashed"></i>
						<?php elseif ($item->state == 2): ?>
							<i class="icon-archive" title="Archived"></i>
						<?php endif; ?>
						</a>
					</td>
				<?php endif; ?>

				<td>
					<?php if (isset($item->checked_out) && $item->checked_out) : ?>
						<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->uEditor, $item->checked_out_time, 'proxyvoters.', $canCheckin); ?>
					<?php endif; ?>
					<?php if (isset($item->state) && $item->state) : ?>
						<a style="color:#3c4d91;" href="<?php echo Route::_('index.php?option=com_gavoting&view=proxyvoter&id='.(int) $item->id); ?>">
							<?php echo $this->escape($item->user_id_name); ?>
						</a>
					<?php else : ?>
						<?php echo $this->escape($item->user_id_name); ?>
					<?php endif; ?>
				</td>
				<td class="center">
					<?php echo $item->voter_id_name; ?>
				</td>
				<td class="center">
					<?php echo $item->created_date; ?>
				</td>

				<?php if ($canEdit || $canDelete): ?>
					<td class="center">
						<?php if ($canEdit): ?>
							<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.edit&id=' . $item->id, false, 2); ?>" class="btn-secondary btn-mini" type="button" title="Edit Record"><i class="icon-edit" ></i></a> &nbsp; &nbsp;
						<?php endif; ?>
						<?php if ($canDelete): ?>
							<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.remove&id=' . $item->id, false, 2); ?>" class="btn-secondary btn-mini delete-button" type="button" title="Delete Record"><i class="icon-trash" ></i></a> &nbsp; &nbsp;
							<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.archive&id=' . $item->id, false, 2); ?>" class="btn-secondary btn-mini" type="button" title="Archive Record"><i class="icon-archive" ></i></a>
						<?php endif; ?>
					</td>
				<?php endif; ?>

			</tr>
		<?php endforeach; ?>
		</tbody>
	</table>
    </div>
	<?php if ($canVote) : ?>
		<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.edit&id=0', false, 0); ?>"
		   class="btn btn-success btn-small"><i class="icon-plus"></i> <?php echo Text::_('COM_GAVOTING_ADD_ITEM'); ?>
		</a>
	<?php endif; ?>

	<input type="hidden" name="task" value=""/>
	<input type="hidden" name="boxchecked" value="0"/>
	<input type="hidden" name="filter_order" value="<?php echo $listOrder; ?>"/>
	<input type="hidden" name="filter_order_Dir" value="<?php echo $listDirn; ?>"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>

<?php if($canDelete) : ?>
<script type="text/javascript">

	jQuery(document).ready(function () {
		jQuery('.delete-button').click(deleteItem);
	});

	function deleteItem() {

		if (!confirm("<?php echo Text::_('COM_GAVOTING_DELETE_MESSAGE'); ?>")) {
			return false;
		}
	}
</script>
<?php endif; ?>
