<?php
/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GaajaxHelper;

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$nominations = $displayData['data'];

// setup the parameters
$allow_proxy = $nominations->params->get('allow_proxy', 0);
$proxy_type = $nominations->params->get('proxy_type');
$dupl_vote = $nominations->params->get('dupl_vote', 1);
$reg_proxy = $nominations->params->get('reg_proxy', 1);
$proxyCnt = GavotingHelper::countProxyVotes($nominations->voting_user);
$prevPos='';
$cntr=0;

//If this is the chairpersons decider vote, reset proxies
if ($nominations->deciderVote) {
    $proxyCnt = 0;
}
// set fields to be hidden if required
$nominations->form->setFieldAttribute('id', 'type', 'hidden');
$nominations->form->setFieldAttribute('id', 'default', $nominations->id);
$nominations->form->setFieldAttribute('ordering', 'type', 'hidden');
$nominations->form->setFieldAttribute('state', 'type', 'hidden');
$nominations->form->setFieldAttribute('created_by', 'type', 'hidden');
$nominations->form->setFieldAttribute('modified_by', 'type', 'hidden');
$nominations->form->setFieldAttribute('created_date', 'type', 'hidden');
$nominations->form->setFieldAttribute('modified_date', 'type', 'hidden');
$nominations->form->setFieldAttribute('user_id', 'type', 'hidden');
$nominations->form->setFieldAttribute('user_id', 'default', $nominations->voting_user);
$nominations->form->setFieldAttribute('cat_id', 'type', 'hidden');
$nominations->form->setFieldAttribute('cat_id', 'default', $nominations->cat_id);

// $posIDs = $nominations->posIDs;
// $nomIDs = $nominations->nomIDs;
?>

<h2><?php echo Text::_('COM_GAVOTING_VOTER_SUBMIT_TEXT'); ?></h2>
<form id="form-voter"
	  action="<?php echo Route::_('index.php?option=com_gavoting&task=voterform.save'); ?>"
	  method="post" class="form-validate form-horizontal" enctype="multipart/form-data">

	<?php echo $nominations->form->renderFieldset('sysinfo'); ?>
	<?php echo $nominations->form->renderField('user_id'); ?>
	<?php echo $nominations->form->renderField('cat_id'); ?>

	<?php echo LayoutHelper::render('default_proxy', array('data' => $nominations), dirname(__FILE__)); ?>

	<?php /* ------------  Cycle through the positions records and show the nomination   ------ */ ?>
	<?php /* the nominations are in an array of position arrays and then each position array is */ ?>
	<?php /* an array of nominations objects. so Key is the posID */ ?>

	<?php foreach ($nominations->nominations AS $posID => $nomins) : $NomCntr = 0; ?>

		<?php if (is_array($nomins) && !empty($nomins)) : ?>

            <div id="form-voter-div" class="control-group">
				<div class="control-label">
					<label id="jform_nom_ids_lbl" for="jform_nom_ids_<?php echo $posID; ?>">
						<?php echo $nomins[0]->position_id_name; ?>
					</label>
				</div>
				<div class="controls extrawide">

					<?php $qtyNoms = \count($nomins); ?>
					<?php foreach ($nomins AS $nom) : $NomCntr++; ?>

						<?php if ($NomCntr == 1) : ?>
							<?php echo '<p> <p /><p>'.Text::sprintf('COM_GAVOTING_MULTIPLE_POSITIONS_PREF', $nom->pos_qty).'<p />'; ?>
						<?php endif; ?>

                        <?php echo $selectList = GaajaxHelper::displayMultiPrefVoteOptions($nom, $qtyNoms, $posID); ?>

					<?php endforeach; ?>

				</div>
			</div>
		<?php endif; ?>

	<?php endforeach; ?>

	<div class="control-group">
		<div class="controls">
			<?php if ($nominations->canSave): ?>
				<button type="submit" class="validate btn btn-primary">
					<?php echo Text::_('JSUBMIT'); ?>
				</button>
			<?php endif; ?>
			<a class="btn btn-secondary"
			   href="<?php echo Route::_('index.php?option=com_gavoting&task=voterform.cancel'); ?>"
			   title="<?php echo Text::_('JCANCEL'); ?>">
				<?php echo Text::_('JCANCEL'); ?>
			</a>
		</div>
	</div>

	<input type="hidden" name="option" value="com_gavoting"/>
	<input type="hidden" name="task" value="voterform.save"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>
