<?php
/**
 * @version    4.7.3
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper;

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$nominations = $displayData['data'];

// setup the parameters
$prefVoting = $nominations->params->get('pref_voting', 0);
$allow_proxy = $nominations->params->get('allow_proxy', 0);
$proxy_type = $nominations->params->get('proxy_type');
$dupl_vote = $nominations->params->get('dupl_vote', 1);
$reg_proxy = $nominations->params->get('reg_proxy', 1);
$proxyCnt = GavotingHelper::countProxyVotes($nominations->voting_user);
$prevPos='';
$cntr=0;

//If this is the chairpersons decider vote, reset proxies
if ($nominations->deciderVote) {
    $proxyCnt = 0;
}
// set fields to be hidden if required
$nominations->form->setFieldAttribute('id', 'type', 'hidden');
$nominations->form->setFieldAttribute('id', 'default', $nominations->id);
$nominations->form->setFieldAttribute('ordering', 'type', 'hidden');
$nominations->form->setFieldAttribute('state', 'type', 'hidden');
$nominations->form->setFieldAttribute('created_by', 'type', 'hidden');
$nominations->form->setFieldAttribute('modified_by', 'type', 'hidden');
$nominations->form->setFieldAttribute('created_date', 'type', 'hidden');
$nominations->form->setFieldAttribute('modified_date', 'type', 'hidden');
$nominations->form->setFieldAttribute('user_id', 'type', 'hidden');
$nominations->form->setFieldAttribute('user_id', 'default', $nominations->voting_user);
$nominations->form->setFieldAttribute('cat_id', 'type', 'hidden');
$nominations->form->setFieldAttribute('cat_id', 'default', $nominations->cat_id);
?>

<h2><?php echo Text::_('COM_GAVOTING_VOTER_SUBMIT_TEXT'); ?></h2>
<form id="form-voter"
	  action="<?php echo Route::_('index.php?option=com_gavoting&task=voterform.save'); ?>"
	  method="post" class="form-validate form-horizontal" enctype="multipart/form-data">

	<?php echo $nominations->form->renderFieldset('sysinfo'); ?>
	<?php echo $nominations->form->renderField('user_id'); ?>
	<?php echo $nominations->form->renderField('cat_id'); ?>

	<?php /* ------------  Set up displayed text explaining Proxy settings   ------------ */ ?>
	<?php if ($allow_proxy) : ?>
        <div>
    		<span style="color:red;">
    			<?php if ($proxy_type == 0) : ?>
    				<?php if ($dupl_vote) : ?>
    					<?php echo Text::_('COM_GAVOTING_PROXYVOTER_GENERAL_DUPYES'); ?>
    				<?php else : ?>
    					<?php echo Text::_('COM_GAVOTING_PROXYVOTER_GENERAL_DUPNO'); ?>
    				<?php endif; ?>
    			<?php elseif ($proxy_type == 1) : ?>
    				<?php echo Text::_('COM_GAVOTING_PROXYVOTER_MESSAGE'); ?><br />
    				<?php echo Text::_('COM_GAVOTING_PROXYVOTER_SPECIFIC'); ?>
    
    			<?php elseif ($proxy_type == 2) : ?>
    				<?php echo Text::_('COM_GAVOTING_PROXYVOTER_MESSAGE'); ?><br />
    				<?php echo Text::_('COM_GAVOTING_PROXY_HYBRID'); ?>
    			<?php endif; ?>
    		</span>
    	</div>
    	<?php if ($proxy_type == 0) : ?>
    		<?php if ($dupl_vote) : ?>
    			<?php if ($proxyCnt) : ?>
    				<div style="color:red; width:100%;" class="spacerheader center"><?php echo Text::sprintf('COM_GAVOTING_PROXYVOTER_COUNT', $proxyCnt); ?></div>
    			<?php endif; ?>
    		<?php else : ?>
    			<div style="color:red; width:100%;" class="spacerheader center"><?php echo Text::_('COM_GAVOTING_PROXYVOTER_WARNING'); ?></div>
    		<?php endif; ?>
    	<?php endif; ?>
    
    	<?php /* ------------  If proxy delegates MUST be registered   --------------------- */ ?>
    	<?php if ($reg_proxy) : ?>
    		<?php if (!$proxyCnt) : ?>
    			<div class="center"><?php echo Text::_('COM_GAVOTING_NOPROXY_REGISTERED'); ?></div>
    		<?php else : ?>
    		    <?php if ($proxy_type == 1 || $proxy_type == 2 || ($proxy_type == 0 && !$dupl_vote)) : ?>
    				<?php echo $nominations->form->renderField('proxy_vote'); ?>
    				<?php echo $nominations->form->renderField('proxy_for'); ?>
    		    <?php else : ?>
    				<input type="hidden" name="jform[proxy_vote]" value="0" />
    				<input type="hidden" name="jform[proxy_for]" value="0" />
    			<?php endif; ?>
    		    <?php if ($proxy_type == 2) : ?>
    				<?php echo $nominations->form->renderField('comment'); ?>
    		    <?php endif; ?>
    		<?php endif; ?>
    	<?php /* ------------  Registration of proxy delegates NOT necessary   -------------- */ ?>
    	<?php else : ?>
    	    <?php if ($proxy_type == 1 || $proxy_type == 2 || ($proxy_type == 0 && !$dupl_vote)) : ?>
    			<?php echo $nominations->form->renderField('proxy_vote'); ?>
    			<?php echo $nominations->form->renderField('proxy_for'); ?>
    	    <?php else : ?>
    			<input type="hidden" name="jform[proxy_vote]" value="0" />
    			<input type="hidden" name="jform[proxy_for]" value="0" />
    		<?php endif; ?>
    	    <?php if ($proxy_type == 2) : ?>
    			<?php echo $nominations->form->renderField('comment'); ?>
    	    <?php endif; ?>
    	<?php endif; ?>
	<?php endif; ?>

	<?php /* ------------  Cycle through the nomination records for choosing   -------------- */ ?>
	<?php /* the nominations are in an array of position arrays and then each position array is an array of nominations */ ?>
	<?php foreach ($nominations->nominations AS $key => $position) : $NomCntr = 0; ?>

		<?php if (is_array($position) && !empty($position)) : ?>

			<div class="control-group">
				<div class="control-label">
					<label id="jform_nom_ids_lbl" for="jform_nom_ids_<?php echo $key; ?>">
						<?php echo $position[0]->position_id_name; ?>
					</label>
				</div>
				<div class="controls extrawide">

					<?php if ($position[0]->pos_qty == 1) : ?>
						<select id="jform_nom_ids_nom_id_<?php echo $key; ?>"
								name="jform[nom_ids][nom_id_<?php echo $key; ?>]">
							<option value="0"> - <?php echo Text::_('COM_GAVOTING_SELECT_NOMINATION'); ?> - </option>
							<?php foreach ($position AS $nom) : ?>
								<option value="<?php echo $nom->id; ?>"><?php echo $nom->nomination_name; ?></option>
							<?php endforeach; ?>
						</select>
                    <?php else : ?>
						<?php foreach ($position AS $nom) : $NomCntr++; ?>
							<?php if ($NomCntr == 1) : ?>
								<?php echo '<p> <p /><p>'.Text::sprintf('COM_GAVOTING_MULTIPLE_POSITIONS', $nom->pos_qty, $nom->pos_qty).'<p />'; ?>
							<?php endif; ?>
							<div class="checkbox">
								<label id="jform_nom_ids_lbl" for="jform_nom_ids_<?php echo $key; ?>" class="checkbox">
									<?php echo $nom->nomination_name; ?>
									<input type="checkbox" name="jform[nom_ids][nom_id_<?php echo $key; ?>][nom_id_<?php echo $nom->id; ?>]" value="<?php echo $nom->id; ?>" />
								</label>
							</div>
						<?php endforeach; ?>
					<?php endif; ?>

				</div>
			</div>
		<?php endif; ?>

	<?php endforeach; ?>

	<div class="control-group">
		<div class="controls">
			<?php if ($nominations->canSave): ?>
				<button type="submit" class="validate btn btn-primary">
					<?php echo Text::_('JSUBMIT'); ?>
				</button>
			<?php endif; ?>
			<a class="btn btn-secondary"
			   href="<?php echo Route::_('index.php?option=com_gavoting&task=voterform.cancel'); ?>"
			   title="<?php echo Text::_('JCANCEL'); ?>">
				<?php echo Text::_('JCANCEL'); ?>
			</a>
		</div>
	</div>

	<input type="hidden" name="option" value="com_gavoting"/>
	<input type="hidden" name="task" value="voterform.save"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>
